@@ -51,7 +51,7 @@ public class ImageLoaderEPS extends AbstractImageLoader {
     }
 
     /** {@inheritDoc} */
-    public Image loadImage(ImageInfo info, Map hints, ImageSessionContext session)
+    public Image loadImage(ImageInfo info, Map<String, Object> hints, ImageSessionContext session)
                 throws ImageException, IOException {
         if (!MimeConstants.MIME_EPS.equals(info.getMimeType())) {
             throw new IllegalArgumentException(
